diff --git a/test/hotspot/jtreg/ProblemList.txt b/test/hotspot/jtreg/ProblemList.txt
index 0f574f7168a..2d1311e3ac1 100644
--- a/test/hotspot/jtreg/ProblemList.txt
+++ b/test/hotspot/jtreg/ProblemList.txt
@@ -53,7 +53,6 @@ compiler/loopopts/TestUnreachableInnerLoop.java 8288981 linux-s390x
 
 compiler/c2/Test8004741.java 8235801 generic-all
 compiler/c2/irTests/TestDuplicateBackedge.java 8318904 generic-all
-compiler/c2/irTests/TestIfMinMax.java 8334816 generic-all
 
 compiler/codecache/jmx/PoolsIndependenceTest.java 8264632 macosx-all
 compiler/codecache/CheckLargePages.java 8332654 linux-x64
diff --git a/test/hotspot/jtreg/compiler/c2/irTests/TestIfMinMax.java b/test/hotspot/jtreg/compiler/c2/irTests/TestIfMinMax.java
index de0b41e73ea..41402036aea 100644
--- a/test/hotspot/jtreg/compiler/c2/irTests/TestIfMinMax.java
+++ b/test/hotspot/jtreg/compiler/c2/irTests/TestIfMinMax.java
@@ -181,19 +181,19 @@ public class TestIfMinMax {
         int[] a = new int[512];
         int[] b = new int[512];
 
-        // Fill from 1 to 50
-        for (int i = 0; i < 50; i++) {
+        // Fill from 1 to 125
+        for (int i = 0; i < 125; i++) {
             a[i] = i + 1;
             b[i] = 1;
         }
 
-        // Fill from -1 to -50
-        for (int i = 50; i < 100; i++) {
-            a[i] = -(i - 49);
+        // Fill from -1 to -125
+        for (int i = 125; i < 250; i++) {
+            a[i] = -(i - 124);
             b[i] = 1;
         }
 
-        for (int i = 100; i < 512; i++) {
+        for (int i = 250; i < 512; i++) {
             a[i] = RANDOM.nextInt();
             b[i] = 1;
         }
@@ -206,19 +206,19 @@ public class TestIfMinMax {
         long[] a = new long[512];
         long[] b = new long[512];
 
-        // Fill from 1 to 50
-        for (int i = 0; i < 50; i++) {
+        // Fill from 1 to 125
+        for (int i = 0; i < 125; i++) {
             a[i] = i + 1;
             b[i] = 1;
         }
 
-        // Fill from -1 to -50
-        for (int i = 50; i < 100; i++) {
-            a[i] = -(i - 49);
+        // Fill from -1 to -125
+        for (int i = 125; i < 250; i++) {
+            a[i] = -(i - 124);
             b[i] = 1;
         }
 
-        for (int i = 100; i < 512; i++) {
+        for (int i = 250; i < 512; i++) {
             a[i] = RANDOM.nextLong();
             b[i] = 1;
         }